#include <stdio.h>
#include <time.h>
#include "sqlite3.h"

void create_report() {
    sqlite3 *db;
    sqlite3_stmt *res;
    FILE *fptr, *fptr2;
    time_t timestamp;
    struct tm *thetime;
    int rc;
    char buffer[256];

    const char* sql = "SELECT packetver, node, systemname, date, gameid FROM ibbs_info ORDER BY node";

    rc = sqlite3_open("ibbs_info.db", &db);
    if (rc) {
        // Error opening the database
        fprintf(stderr, "Error opening ibbs_info.db: %s\n", sqlite3_errmsg(db));
        return;
    }

    sqlite3_busy_timeout(db, 5000);

    rc = sqlite3_prepare_v2(db, sql, -1, &res, 0);
    if (rc != SQLITE_OK) {
        fprintf(stderr, "Error preparing statement: %s\n", sqlite3_errmsg(db));
        return;
    }

    fptr = fopen("report.txt", "w");
    if (!fptr) {
        sqlite3_finalize(res);
        sqlite3_close(db);
        return;
    }
    
    fptr2 = fopen("report_header.txt", "r");
    if (fptr2) {
        fgets(buffer, 256, fptr2);
        while (!feof(fptr2)) {
            fprintf(fptr, "%s", buffer);
            fgets(buffer, 256, fptr2);
        }
        fclose(fptr2);
    }

    fprintf(fptr, "+-----------------------------------------------------------------------------+\n");
    fprintf(fptr, "|NODE | SYSTEM NAME                      |VERSION|GAME ID| LAST PACKET        |\n");
    fprintf(fptr, "+-----------------------------------------------------------------------------+\n");
    while (sqlite3_step(res) == SQLITE_ROW) {
        timestamp = sqlite3_column_int(res, 3);
        thetime = localtime(&timestamp);
        fprintf(fptr, "| %3d | %-32.32s | %-5.5s | %5d | %04d-%02d-%02d  %02d:%02d  |\n", sqlite3_column_int(res, 1), sqlite3_column_text(res, 2), sqlite3_column_text(res, 0), sqlite3_column_int(res, 4), thetime->tm_year + 1900, thetime->tm_mon + 1, thetime->tm_mday, thetime->tm_hour, thetime->tm_min);
    }
    fprintf(fptr, "+-----------------------------------------------------------------------------+\n");
    fclose(fptr);
    sqlite3_finalize(res);
    sqlite3_close(db);
}


int main(int argc, char **argv) {
    create_report();
    return 0;
}